@@ -11,9 +11,10 @@ use Chart::Plotly::Trace::Choropleth::Hoverlabel;
 use Chart::Plotly::Trace::Choropleth::Marker;
 use Chart::Plotly::Trace::Choropleth::Selected;
 use Chart::Plotly::Trace::Choropleth::Stream;
+use Chart::Plotly::Trace::Choropleth::Transform;
 use Chart::Plotly::Trace::Choropleth::Unselected;
 
-our $VERSION = '0.018';    # VERSION
+our $VERSION = '0.019';    # VERSION
 
 # ABSTRACT: The data that describes the choropleth value-to-color mapping is set in `z`. The geographic locations corresponding to each value in `z` are set in `locations`.
 
@@ -180,6 +181,9 @@ has textsrc => ( is            => "rw",
                  documentation => "Sets the source reference on plot.ly for  text .",
 );
 
+has transforms => ( is  => "rw",
+                    isa => "ArrayRef|ArrayRef[Chart::Plotly::Trace::Choropleth::Transform]", );
+
 has uid => ( is  => "rw",
              isa => "Str", );
 
@@ -233,7 +237,7 @@ Chart::Plotly::Trace::Choropleth - The data that describes the choropleth value-
 
 =head1 VERSION
 
-version 0.018
+version 0.019
 
 =head1 SYNOPSIS
 
@@ -512,6 +516,8 @@ Sets the text elements associated with each location.
 
 Sets the source reference on plot.ly for  text .
 
+=item * transforms
+
 =item * uid
 
 =item * unselected
