@@ -11,8 +11,9 @@ use Chart::Plotly::Trace::Contourcarpet::Contours;
 use Chart::Plotly::Trace::Contourcarpet::Hoverlabel;
 use Chart::Plotly::Trace::Contourcarpet::Line;
 use Chart::Plotly::Trace::Contourcarpet::Stream;
+use Chart::Plotly::Trace::Contourcarpet::Transform;
 
-our $VERSION = '0.018';    # VERSION
+our $VERSION = '0.019';    # VERSION
 
 # ABSTRACT: Plots contours on either the first carpet axis or the carpet axis with a matching `carpet` attribute. Data `z` is interpreted as matching that of the corresponding carpet axis.
 
@@ -240,6 +241,9 @@ has textsrc => ( is            => "rw",
                  documentation => "Sets the source reference on plot.ly for  text .",
 );
 
+has transforms => ( is  => "rw",
+                    isa => "ArrayRef|ArrayRef[Chart::Plotly::Trace::Contourcarpet::Transform]", );
+
 has transpose => ( is            => "rw",
                    isa           => "Bool",
                    documentation => "Transposes the z data.",
@@ -263,7 +267,7 @@ has xaxis => (
 has yaxis => (
     is => "rw",
     documentation =>
-      "Sets a reference between this trace's y coordinates and a 2D cartesian y axis. If *y* (the default value), the y coordinates refer to `layout.yaxis`. If *y2*, the y coordinates refer to `layout.xaxis2`, and so on.",
+      "Sets a reference between this trace's y coordinates and a 2D cartesian y axis. If *y* (the default value), the y coordinates refer to `layout.yaxis`. If *y2*, the y coordinates refer to `layout.yaxis2`, and so on.",
 );
 
 has z => ( is            => "rw",
@@ -307,7 +311,7 @@ Chart::Plotly::Trace::Contourcarpet - Plots contours on either the first carpet
 
 =head1 VERSION
 
-version 0.018
+version 0.019
 
 =head1 SYNOPSIS
 
@@ -532,6 +536,8 @@ Sets the text elements associated with each z value.
 
 Sets the source reference on plot.ly for  text .
 
+=item * transforms
+
 =item * transpose
 
 Transposes the z data.
@@ -548,7 +554,7 @@ Sets a reference between this trace's x coordinates and a 2D cartesian x axis. I
 
 =item * yaxis
 
-Sets a reference between this trace's y coordinates and a 2D cartesian y axis. If *y* (the default value), the y coordinates refer to `layout.yaxis`. If *y2*, the y coordinates refer to `layout.xaxis2`, and so on.
+Sets a reference between this trace's y coordinates and a 2D cartesian y axis. If *y* (the default value), the y coordinates refer to `layout.yaxis`. If *y2*, the y coordinates refer to `layout.yaxis2`, and so on.
 
 =item * z
 
