@@ -10,10 +10,11 @@ use Chart::Plotly::Trace::Histogram2d::Colorbar;
 use Chart::Plotly::Trace::Histogram2d::Hoverlabel;
 use Chart::Plotly::Trace::Histogram2d::Marker;
 use Chart::Plotly::Trace::Histogram2d::Stream;
+use Chart::Plotly::Trace::Histogram2d::Transform;
 use Chart::Plotly::Trace::Histogram2d::Xbins;
 use Chart::Plotly::Trace::Histogram2d::Ybins;
 
-our $VERSION = '0.018';    # VERSION
+our $VERSION = '0.019';    # VERSION
 
 # ABSTRACT: The sample data from which statistics are computed is set in `x` and `y` (where `x` and `y` represent marginal distributions, binning is set in `xbins` and `ybins` in this case) or `z` (where `z` represent the 2D distribution and binning set, binning is set by `x` and `y` in this case). The resulting distribution is visualized as a heatmap.
 
@@ -187,6 +188,9 @@ has showscale => ( is            => "rw",
 has stream => ( is  => "rw",
                 isa => "Maybe[HashRef]|Chart::Plotly::Trace::Histogram2d::Stream", );
 
+has transforms => ( is  => "rw",
+                    isa => "ArrayRef|ArrayRef[Chart::Plotly::Trace::Histogram2d::Transform]", );
+
 has uid => ( is  => "rw",
              isa => "Str", );
 
@@ -237,7 +241,7 @@ has y => ( is            => "rw",
 has yaxis => (
     is => "rw",
     documentation =>
-      "Sets a reference between this trace's y coordinates and a 2D cartesian y axis. If *y* (the default value), the y coordinates refer to `layout.yaxis`. If *y2*, the y coordinates refer to `layout.xaxis2`, and so on.",
+      "Sets a reference between this trace's y coordinates and a 2D cartesian y axis. If *y* (the default value), the y coordinates refer to `layout.yaxis`. If *y2*, the y coordinates refer to `layout.yaxis2`, and so on.",
 );
 
 has ybins => ( is  => "rw",
@@ -313,7 +317,7 @@ Chart::Plotly::Trace::Histogram2d - The sample data from which statistics are co
 
 =head1 VERSION
 
-version 0.018
+version 0.019
 
 =head1 SYNOPSIS
 
@@ -459,6 +463,8 @@ Determines whether or not a colorbar is displayed for this trace.
 
 =item * stream
 
+=item * transforms
+
 =item * uid
 
 =item * visible
@@ -493,7 +499,7 @@ Sets the sample data to be binned on the y axis.
 
 =item * yaxis
 
-Sets a reference between this trace's y coordinates and a 2D cartesian y axis. If *y* (the default value), the y coordinates refer to `layout.yaxis`. If *y2*, the y coordinates refer to `layout.xaxis2`, and so on.
+Sets a reference between this trace's y coordinates and a 2D cartesian y axis. If *y* (the default value), the y coordinates refer to `layout.yaxis`. If *y2*, the y coordinates refer to `layout.yaxis2`, and so on.
 
 =item * ybins
 
