@@ -15,8 +15,9 @@ use Chart::Plotly::Trace::Scatter3d::Marker;
 use Chart::Plotly::Trace::Scatter3d::Projection;
 use Chart::Plotly::Trace::Scatter3d::Stream;
 use Chart::Plotly::Trace::Scatter3d::Textfont;
+use Chart::Plotly::Trace::Scatter3d::Transform;
 
-our $VERSION = '0.018';    # VERSION
+our $VERSION = '0.019';    # VERSION
 
 # ABSTRACT: The data visualized as scatter point or lines in 3D dimension is set in `x`, `y`, `z`. Text (appearing either on the chart or on hover only) is via `text`. Bubble charts are achieved by setting `marker.size` and/or `marker.color` Projections are achieved via `projection`. Surface fills are achieved via `surfaceaxis`.
 
@@ -220,6 +221,9 @@ has textsrc => ( is            => "rw",
                  documentation => "Sets the source reference on plot.ly for  text .",
 );
 
+has transforms => ( is  => "rw",
+                    isa => "ArrayRef|ArrayRef[Chart::Plotly::Trace::Scatter3d::Transform]", );
+
 has uid => ( is  => "rw",
              isa => "Str", );
 
@@ -301,7 +305,7 @@ Chart::Plotly::Trace::Scatter3d - The data visualized as scatter point or lines
 
 =head1 VERSION
 
-version 0.018
+version 0.019
 
 =head1 SYNOPSIS
 
@@ -472,6 +476,8 @@ Sets the source reference on plot.ly for  textposition .
 
 Sets the source reference on plot.ly for  text .
 
+=item * transforms
+
 =item * uid
 
 =item * visible
